==> fetch.php?media=download_software:mae3xx:mae320_rootfs_trusty_v2_6_0.tar.xz: opt/mae3xx/app/AppServer/Handlers/PPPoE.py <==
# -*- coding: utf-8 -*-
from Handlers import BaseHandler
import os
#-------------------------------------------------------------------------------
#
#-------------------------------------------------------------------------------
class PPPoE(BaseHandler.BaseHandler):
	#=======================================================
	# 
	#=======================================================
	def __init__(self):
		self.config = "/etc/default/pppoe"
		self.keys = ['START','INTERFACE','DEFAULTROUTE','ACCOUNT','PASSWORD','MTU']
		self.interface = "/etc/network/interfaces.d/dsl-provider"
		self.name = 'PPPoE'
	#=======================================================
	# 
	#=======================================================
	def Get(self, request):

		status = 200
		type = request.query.type
		if type == 'config':
			result = self.readConfig()
		elif type == 'status':
			result = self.getStatus()

		return result, status

	#=======================================================
	# 
	#=======================================================
	def Put(self, request):

		status = 200

		if os.path.exists('/sys/class/net/br0') and request.json['start'] == 'yes':
			self.log('br0 interface used. ')
			status = 409
		else:
			self.writeConfig(request.json)

			self.call(['ifdown', 'dsl-provider'])
			if request.json['start'] == 'yes':
				self.call(['/usr/local/sbin/gen_pppoeconfig'])
				self.call(['ifup', 'dsl-provider'])

			else:
				if os.path.exists(self.interface):
					os.remove(self.interface)
		return status

	#=======================================================
	# 
	#=======================================================
	def readConfig(self):

		conf = {}
		demand = False

		for key in self.keys:
			conf[key.lower()] = ''

		config = open(self.config, "r")
		for line in config:
			if line.startswith('#') == True:
				pass
			else:
				sline = line.strip('\n').split('=')
				if len(sline) > 1 and sline[1]:
					conf[sline[0].lower()] = sline[1]
		if os.path.exists('/sys/class/net/br0'):
			conf['bridge'] = 'true'
		else:
			conf['bridge'] = 'false'
		return conf

	#=======================================================
	# 
	#=======================================================
	def writeConfig(self, args):
		
		config =[]
		
		for key in self.keys:
			value = ''
			value = args[key.lower()]
			config.append('='.join((key, value)))

		fd = open(self.config, 'w')
		fd.write('\n'.join(config))

	#=======================================================
	# 
	#=======================================================
	def getStatus(self):

		status = {'carrier':'0', 'ipaddress':''}
		addr = self.getAddr('ppp1')
		if addr:
			status['carrier'] = '1'
			status['ipaddress'] = addr

		return status

==> fetch.php?media=download_software:mae3xx:mae320_rootfs_trusty_v2_6_8.tar.xz: opt/mae3xx/app/AppServer/Handlers/PPPoE.py <==
# -*- coding: utf-8 -*-
from Handlers import BaseHandler
import os
#-------------------------------------------------------------------------------
#
#-------------------------------------------------------------------------------
class PPPoE(BaseHandler.BaseHandler):
	#=======================================================
	# 
	#=======================================================
	def __init__(self):
		self.config = "/etc/default/pppoe"
		self.keys = ['START','INTERFACE','DEFAULTROUTE','ACCOUNT','PASSWORD','MTU','SERVICENAME']
		self.interface = "/etc/network/interfaces.d/dsl-provider"
		self.name = 'PPPoE'
	#=======================================================
	# 
	#=======================================================
	def Get(self, request):

		status = 200
		type = request.query.type
		if type == 'config':
			result = self.readConfig()
		elif type == 'status':
			result = self.getStatus()

		return result, status

	#=======================================================
	# 
	#=======================================================
	def Put(self, request):

		status = 200

		if os.path.exists('/sys/class/net/br0') and request.json['start'] == 'yes':
			self.log('br0 interface used. ')
			status = 409
		else:
			self.writeConfig(request.json)

			self.call(['ifdown', 'dsl-provider'])
			if request.json['start'] == 'yes':
				self.call(['/usr/local/sbin/gen_pppoeconfig'])
				self.call(['ifup', 'dsl-provider'])

			else:
				if os.path.exists(self.interface):
					os.remove(self.interface)
		return status

	#=======================================================
	# 
	#=======================================================
	def readConfig(self):

		conf = {}
		demand = False

		for key in self.keys:
			conf[key.lower()] = ''

		config = open(self.config, "r")
		for line in config:
			if line.startswith('#') == True:
				pass
			else:
				sline = line.strip('\n').split('=')
				if len(sline) > 1 and sline[1]:
					conf[sline[0].lower()] = sline[1]
		if os.path.exists('/sys/class/net/br0'):
			conf['bridge'] = 'true'
		else:
			conf['bridge'] = 'false'
		return conf

	#=======================================================
	# 
	#=======================================================
	def writeConfig(self, args):
		
		config =[]
		
		for key in self.keys:
			value = ''
			value = args[key.lower()]
			config.append('='.join((key, value)))

		fd = open(self.config, 'w')
		fd.write('\n'.join(config))

	#=======================================================
	# 
	#=======================================================
	def getStatus(self):

		status = {'carrier':'0', 'ipaddress':''}
		addr = self.getAddr('ppp1')
		if addr:
			status['carrier'] = '1'
			status['ipaddress'] = addr

		return status
